import React, { useState, useRef, useEffect } from 'react';
import {
  StyleSheet,
  ScrollView,
  TouchableOpacity,
  View,
  Text,
} from 'react-native';
import { Input, BottomSheet, ListItem, Button } from '@rneui/themed';
import { Task, RobotAction, InputParam } from '../types/task';
import { useTasks } from '../context/TasksContext';

interface TaskFormProps {
  task: Task;
  onTaskChange: (updatedTask: Task) => void;
}

const TaskForm: React.FC<TaskFormProps> = ({ task, onTaskChange }) => {
  const { locations, payloads, robotActions } = useTasks();
  const [isVisible, setIsVisible] = useState(false);
  const [currentField, setCurrentField] = useState('');
  const [currentItems, setCurrentItems] = useState<
    { label: string; value: string }[]
  >([]);

  useEffect(() => {
    console.log('TaskForm task prop updated:', task);
  }, [task]);

  const handleParamChange = (field: string, value: string | RobotAction) => {
    const currentParam = task.parameters[field] || {};
    const updatedTask = {
      ...task,
      parameters: {
        ...task.parameters,
        [field]: {
          ...currentParam,
          value: value,
        },
      },
    };
    onTaskChange(updatedTask);
  };

  const openBottomSheet = (
    field: string,
    items: { label: string; value: string }[],
  ) => {
    setCurrentField(field);
    setCurrentItems(items);
    setIsVisible(true);
  };

  const renderDropdown = (
    name: string,
    label: string,
    value: string,
    items: { label: string; value: string }[],
  ) => (
    <TouchableOpacity onPress={() => openBottomSheet(name, items)}>
      <Input
        label={label}
        value={value}
        editable={false}
        rightIcon={{ name: 'arrow-drop-down' }}
      />
    </TouchableOpacity>
  );

  const renderFormInput = (param: InputParam) => {
    const parameter = task.parameters?.[param.name];
    const value = parameter?.value || param.defaultValue;

    switch (param.type) {
      case 'String':
      case 'STRING': //
        return (
          <Input
            key={param.name}
            label={param.label}
            value={value as string}
            onChangeText={text => handleParamChange(param.name, text)}
            placeholder={param.remark}
          />
        );
      default:
        return (
          <Input
            key={param.name}
            label={param.label}
            value={value as string}
            onChangeText={text => handleParamChange(param.name, text)}
            placeholder={param.remark}
          />
        );
    }
  };

  return (
    <ScrollView contentContainerStyle={styles.container}>
      <Input
        label="任务名称"
        value={task.name}
        onChangeText={text => onTaskChange({ ...task, name: text })}
      />

      {task.detail && task.detail.inputParams ? (
        task.detail.inputParams.map(param => renderFormInput(param))
      ) : (
        <Text>正在加载任务参数... {task.detail}</Text>
      )}

      <BottomSheet
        isVisible={isVisible}
        onBackdropPress={() => setIsVisible(false)}
      >
        <ScrollView>
          {currentItems.map((item, index) => (
            <ListItem
              key={index}
              onPress={() => {
                handleParamChange(currentField, item.value);
                setIsVisible(false);
              }}
            >
              <ListItem.Content>
                <ListItem.Title>{item.label}</ListItem.Title>
              </ListItem.Content>
            </ListItem>
          ))}
        </ScrollView>
      </BottomSheet>
    </ScrollView>
  );
};

const styles = StyleSheet.create({
  container: {
    padding: 16,
  },
});

export default TaskForm;
